==> peony-extensions_3.14.1.0.orig.tar.gz: peony-extensions-3.14.1.0/peony-extension-computer-view/peony-extension-computer-view_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="155"/>
        <source>You should mount volume first</source>
        <translation>Svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Okolní počítače</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="62"/>
        <source>Remote</source>
        <translation>Vzdálené</translation>
    </message>
</context>
<context>
    <name>ComputerUserShareItem</name>
    <message>
        <location filename="computer-view/computer-user-share-item.cpp" line="20"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="54"/>
        <source>Volume</source>
        <translation>Svazek</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="63"/>
        <location filename="computer-view/computer-volume-item.cpp" line="110"/>
        <source>File System</source>
        <translation>Souborový systém</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="174"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="132"/>
        <source>Connect a server</source>
        <translation>Připojit k serveru</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">sftp://, atd…</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="150"/>
        <location filename="computer-view-container.cpp" line="155"/>
        <source>Unmount</source>
        <translation>Odpojit</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="162"/>
        <source>Eject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="188"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="206"/>
        <location filename="computer-view-container.cpp" line="223"/>
        <source>Property</source>
        <translation>Vlastnost</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="208"/>
        <source>You have to mount this volume first</source>
        <translation>Tento svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRename</name>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="163"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="175"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="175"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="179"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="187"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="193"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="206"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="179"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="187"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="193"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="206"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Tento počítač</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>Zobrazit disky, síť a osobní složky.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="364"/>
        <source>It need to synchronize before operating the device,place wait!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="626"/>
        <source>The device has been mount successfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="648"/>
        <source>Data synchronization is complete,the device has been unmount successfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="656"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="657"/>
        <location filename="computer-view/computer-volume-item.cpp" line="661"/>
        <location filename="computer-view/computer-volume-item.cpp" line="665"/>
        <source>Unmount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="657"/>
        <location filename="computer-view/computer-volume-item.cpp" line="665"/>
        <source>Error: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="660"/>
        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="661"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="688"/>
        <location filename="computer-view/computer-volume-item.cpp" line="703"/>
        <source>Eject failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-extension-computer-view/peony-extension-computer-view_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="155"/>
        <source>You should mount volume first</source>
        <translation>Svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Okolní počítače</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="84"/>
        <source>Remote</source>
        <translation>Vzdálené</translation>
    </message>
</context>
<context>
    <name>ComputerUserShareItem</name>
    <message>
        <location filename="computer-view/computer-user-share-item.cpp" line="20"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="54"/>
        <source>Volume</source>
        <translation>Svazek</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="63"/>
        <location filename="computer-view/computer-volume-item.cpp" line="115"/>
        <source>File System</source>
        <translation>Souborový systém</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="179"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Intel::ComputerItemDelegate</name>
    <message>
        <location filename="computer-view-intel/intel-computer-item-delegate.cpp" line="150"/>
        <source>You should mount volume first</source>
        <translation type="unfinished">Svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerNetworkItem</name>
    <message>
        <location filename="computer-view-intel/intel-computer-network-item.cpp" line="47"/>
        <source>Network Neighborhood</source>
        <translation type="unfinished">Okolní počítače</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view-intel/intel-computer-remote-volume-item.cpp" line="56"/>
        <source>Remote</source>
        <translation type="unfinished">Vzdálené</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="105"/>
        <source>Connect a server</source>
        <translation type="unfinished">Připojit k serveru</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="139"/>
        <source>Unmount</source>
        <translation type="unfinished">Odpojit</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="145"/>
        <source>Eject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="155"/>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="171"/>
        <source>Property</source>
        <translation type="unfinished">Vlastnost</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="157"/>
        <source>You have to mount this volume first</source>
        <translation type="unfinished">Tento svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>Intel::ComputerVolumeItem</name>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="39"/>
        <source>Volume</source>
        <translation type="unfinished">Svazek</translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="47"/>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="109"/>
        <source>System Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="99"/>
        <source>User Disk</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="131"/>
        <source>Connect a server</source>
        <translation>Připojit k serveru</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">sftp://, atd…</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="159"/>
        <location filename="computer-view-container.cpp" line="164"/>
        <source>Unmount</source>
        <translation>Odpojit</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="171"/>
        <source>Eject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="208"/>
        <location filename="computer-view-container.cpp" line="224"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="245"/>
        <location filename="computer-view-container.cpp" line="285"/>
        <source>Property</source>
        <translation>Vlastnost</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="247"/>
        <source>You have to mount this volume first</source>
        <translation>Tento svazek je třeba nejprve připojit (mount)</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="265"/>
        <source>Open In New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="275"/>
        <source>Open In New Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DriveRename</name>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="166"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="178"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="178"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="182"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="190"/>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="196"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="182"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="190"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="196"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Tento počítač</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>Zobrazit disky, síť a osobní složky.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="314"/>
        <location filename="computer-view/computer-volume-item.cpp" line="377"/>
        <source>It need to synchronize before operating the device,place wait!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="669"/>
        <source>The device has been mount successfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="690"/>
        <location filename="computer-view/computer-volume-item.cpp" line="725"/>
        <location filename="computer-view/computer-volume-item.cpp" line="756"/>
        <source>Data synchronization is complete,the device has been unmount successfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="517"/>
        <location filename="computer-view/computer-volume-item.cpp" line="697"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="519"/>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="528"/>
        <location filename="computer-view/computer-volume-item.cpp" line="698"/>
        <location filename="computer-view/computer-volume-item.cpp" line="702"/>
        <location filename="computer-view/computer-volume-item.cpp" line="706"/>
        <source>Unmount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="698"/>
        <location filename="computer-view/computer-volume-item.cpp" line="706"/>
        <source>Error: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="520"/>
        <source>Error: %1
Do you want to unmount forcely?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="527"/>
        <location filename="computer-view/computer-volume-item.cpp" line="701"/>
        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="529"/>
        <location filename="computer-view/computer-volume-item.cpp" line="702"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="553"/>
        <location filename="computer-view/computer-volume-item.cpp" line="732"/>
        <location filename="computer-view/computer-volume-item.cpp" line="752"/>
        <source>Eject failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="554"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-intel/intel-computer-volume-item.cpp" line="555"/>
        <source>Eject Anyway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="314"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../peony-drive-rename/drive-rename.cpp" line="314"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="63"/>
        <location filename="computer-view-intel/intel-computer-view-container.cpp" line="59"/>
        <source>log remote error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
